<?php

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Handle file uploads via XMLHttpRequest
 */
class qqUploadedFileXhr {
    /**
     * Save the file to the specified path
     * @return boolean TRUE on success
     */
    function save($path) {
        $input = fopen("php://input", "r");
        $temp = tmpfile();
        $realSize = stream_copy_to_stream($input, $temp);
        fclose($input);

        if ($realSize != $this->getSize()){
            return false;
        }

        $target = fopen($path, "w");
        fseek($temp, 0, SEEK_SET);
        stream_copy_to_stream($temp, $target);
        fclose($target);

        return true;
    }
    function getName() {
        return $_GET['qqfile'];
    }
    function getSize() {
        if (isset($_SERVER["CONTENT_LENGTH"])){
            return (int)$_SERVER["CONTENT_LENGTH"];
        } else {
            //throw new Exception('Getting content length is not supported.');
            return false;
        }
    }
}

/**
 * Handle file uploads via regular form post (uses the $_FILES array)
 */
class qqUploadedFileForm {
    /**
     * Save the file to the specified path
     * @return boolean TRUE on success
     */
    function save($path) {
        if(!move_uploaded_file($_FILES['qqfile']['tmp_name'], $path)){
            return false;
        }
        return true;
    }
    function getName() {
        return $_FILES['qqfile']['name'];
    }
    function getSize() {
        return $_FILES['qqfile']['size'];
    }
}

class qqFileUploader {
    var $allowedExtensions = array();
    var $sizeLimit = 10485760;
    var $file;

    function __construct(array $allowedExtensions = array(), $sizeLimit = 10485760){
        $allowedExtensions = array_map("strtolower", $allowedExtensions);

        $this->allowedExtensions = $allowedExtensions;
        $this->sizeLimit = $sizeLimit;

        //$this->checkServerSettings();

        if (isset($_GET['qqfile'])) {
            $this->file = new qqUploadedFileXhr();
        } elseif (isset($_FILES['qqfile'])) {
            $this->file = new qqUploadedFileForm();
        } else {
            $this->file = false;
        }
    }

    function checkServerSettings(){
        $postSize = $this->toBytes(ini_get('post_max_size'));
        $uploadSize = $this->toBytes(ini_get('upload_max_filesize'));

        if ($postSize < $this->sizeLimit || $uploadSize < $this->sizeLimit){
            $size = max(1, $this->sizeLimit / 1024 / 1024) . 'M';

            $message = sprintf( __( 'increase post_max_size and upload_max_filesize to %s', 'bp-activity-plus-reloaded' ), $size );

	        die( "{'error':$message}" );
        }
    }

    function toBytes($str){
        $val = trim($str);
        $last = strtolower($str[strlen($str)-1]);
        switch($last) {
            case 'g': $val *= 1024;
            case 'm': $val *= 1024;
            case 'k': $val *= 1024;
        }
        return $val;
    }

    /**
     * Returns array('success'=>true, 'file'=>$filename) or array('error'=>'error message')
     */
    function handleUpload($uploadDirectory, $replaceOldFile = FALSE){
        if (!is_writable($uploadDirectory)){
	        $error_message = __( "Server error. Upload directory isn't writable.", 'bp-activity-plus-reloaded' );
            return array('error' => $error_message);
        }

	    if ( ! $this->file ) {
		    return array( 'error' => __( 'No files were uploaded.', 'bp-activity-plus-reloaded' ) );
	    }

        $size = $this->file->getSize();

	    if ( $size == 0 ) {
		    return array( 'error' => __( 'File is empty', 'bp-activity-plus-reloaded' ) );
	    }

	    if ( $size > $this->sizeLimit ) {
		    return array( 'error' => __( 'File is too large', 'bp-activity-plus-reloaded' ) );
	    }

        $pathinfo = pathinfo($this->file->getName());
        $filename = strtolower($pathinfo['filename']);
        //$filename = md5(uniqid());
        $ext = strtolower($pathinfo['extension']);

	    if ( $this->allowedExtensions && ! in_array( strtolower( $ext ), $this->allowedExtensions ) ) {
		    $these = implode( ', ', $this->allowedExtensions );

		    $error_message = sprintf( __( 'File has an invalid extension, it should be one of %s .', 'bp-activity-plus-reloaded' ), $these );

		    return array( 'error' => $error_message );
	    }

        if(!$replaceOldFile){
            /// don't overwrite previous files that were uploaded
            while (file_exists($uploadDirectory . $filename . '.' . $ext)) {
                $filename .= rand(10, 99);
            }
        }
        $filename = sanitize_file_name($filename);

	    if ( $this->file->save( $uploadDirectory . $filename . '.' . $ext ) ) {
		    return array( 'success' => true, 'file' => $filename . '.' . $ext );
	    } else {
		    return array(
			    'error' => __( 'Could not save uploaded file. The upload was cancelled, or server error encountered', 'bp-activity-plus-reloaded' )
		    );
	    }

    }
}
